@@ -5,14 +5,15 @@ from mesures.p1 import P1
 
 
 class P1D(P1):
-    def __init__(self, data, distributor=None, comer=None, compression='bz2', columns=COLUMNS):
+    def __init__(self, data, distributor=None, comer=None, compression='bz2', columns=COLUMNS, version=0):
         """
         :param data: list of dicts or absolute file_path
         :param distributor: str distributor REE code
         :param comer: str comer REE code
         :param compression: 'bz2', 'gz'... OR False otherwise
         """
-        super(P1D, self).__init__(data, distributor=distributor, compression=compression, columns=columns)
+        super(P1D, self).__init__(data, distributor=distributor, compression=compression,
+                                  columns=columns, version=version)
         self.prefix = 'P1D'
         self.comer = comer
 
